/**
 * @file
 * Defines Javascript behaviors for the etracker module.
 */
(function (drupalSettings) {
  'use strict';

  // Attach mousedown, keyup, touchstart events to document only
  ['mousedown', 'keyup', 'touchstart'].forEach(function (e) {
    document.querySelector('body').addEventListener(e, function (event) {
      if(event.target.tagName === 'A' || event.target.tagName === 'AREA') {
        // Mailto link clicked.
        if (drupalSettings.etracker.track.mailto && event.target.href.startsWith('mailto:')) {
          _etracker.sendEvent(new et_ClickEvent(('E-Mail:%20' + event.target.href.substring(7), 'E-Mail')));
        }
        // Download link clicked.
        else if (drupalSettings.etracker.track.download && (new RegExp("\\.(pdf|doc|docx|xls|xlsx|ppt|pptx|txt)(\\?|$)").test(event.target.href))) {
          _etracker.sendEvent(new et_UserDefinedEvent(event.target.href, 'Download'));
        }
        // External link clicked.
        else if (drupalSettings.etracker.track.external && event.target.host !== window.location.host) {
          _etracker.sendEvent(new et_UserDefinedEvent('External link:%20' + event.target.href, ''));
        }
      }
    });
  });

  // Trigger events for each message being displayed.
  if (drupalSettings.etracker.messages.length > 0) {
    for (var i in drupalSettings.etracker.messages) {
      _etracker.sendEvent(new et_UserDefinedEvent(drupalSettings.etracker.messages[i].text, 'Message', drupalSettings.etracker.messages[i].type, ''));
    }
  }

  // Trigger events for internal search terms.
  if (drupalSettings.etracker.search_terms !== '') {
    if (drupalSettings.etracker.number_of_search_results === undefined) {
      drupalSettings.etracker.number_of_search_results = 0;
    }
    _etracker.sendEvent(new et_UserDefinedEvent(drupalSettings.etracker.search_terms, 'Internal Search', 'Search terms', ''));
    _etracker.sendEvent(new et_UserDefinedEvent(drupalSettings.etracker.number_of_search_results, 'Internal Search', 'Number of results', ''));
  }

})(drupalSettings);
